@@ -49,7 +49,7 @@ using namespace QuantLib;
 #if defined(QL_ENABLE_SESSIONS)
 namespace QuantLib {
 
-    Integer sessionId() { return 0; }
+    ThreadKey sessionId() { return {}; }
 
 }
 #endif
@@ -166,11 +166,11 @@ int main(int, char* []) {
 
         // defining the swaptions to be used in model calibration
         std::vector<Period> swaptionMaturities;
-        swaptionMaturities.push_back(Period(1, Years));
-        swaptionMaturities.push_back(Period(2, Years));
-        swaptionMaturities.push_back(Period(3, Years));
-        swaptionMaturities.push_back(Period(4, Years));
-        swaptionMaturities.push_back(Period(5, Years));
+        swaptionMaturities.emplace_back(1, Years);
+        swaptionMaturities.emplace_back(2, Years);
+        swaptionMaturities.emplace_back(3, Years);
+        swaptionMaturities.emplace_back(4, Years);
+        swaptionMaturities.emplace_back(5, Years);
 
         std::vector<ext::shared_ptr<BlackCalibrationHelper> > swaptions;
 
