@@ -26,10 +26,7 @@
 #include <ql/currencies/europe.hpp>
 #include <ql/time/calendars/target.hpp>
 #include <ql/time/daycounters/actual365fixed.hpp>
-
-#include <boost/timer.hpp>
-#include <boost/function.hpp>
-
+#include <string>
 #include <iostream>
 #include <iomanip>
 
@@ -39,7 +36,7 @@ using namespace QuantLib;
 #if defined(QL_ENABLE_SESSIONS)
 namespace QuantLib {
 
-    Integer sessionId() { return 0; }
+    ThreadKey sessionId() { return {}; }
 
 }
 #endif
@@ -54,7 +51,6 @@ int main(int, char* []) {
 
     try {
 
-        boost::timer timer;
         std::cout << std::endl;
 
         Calendar calendar = TARGET();
@@ -72,13 +68,12 @@ int main(int, char* []) {
         std::vector<Real> hazardRates(3, -std::log(1.-0.01));
         std::vector<std::string> names;
         for(Size i=0; i<hazardRates.size(); i++)
-            names.push_back(std::string("Acme") + 
-                boost::lexical_cast<std::string>(i));
+            names.push_back(std::string("Acme") + std::to_string(i));
         std::vector<Handle<DefaultProbabilityTermStructure> > defTS;
-        for(Size i=0; i<hazardRates.size(); i++)
-            defTS.push_back(Handle<DefaultProbabilityTermStructure>(
-                ext::make_shared<FlatHazardRate>(0, TARGET(), hazardRates[i], 
-                    Actual365Fixed())));
+        defTS.reserve(hazardRates.size());
+        for (double& hazardRate : hazardRates)
+            defTS.emplace_back(
+                ext::make_shared<FlatHazardRate>(0, TARGET(), hazardRate, Actual365Fixed()));
         std::vector<Issuer> issuers;
         for(Size i=0; i<hazardRates.size(); i++) {
             std::vector<QuantLib::Issuer::key_curve_pair> curves(1, 
@@ -86,7 +81,7 @@ int main(int, char* []) {
                     EURCurrency(), QuantLib::SeniorSec,
                     Period(), 1. // amount threshold
                     ), defTS[i]));
-            issuers.push_back(Issuer(curves));
+            issuers.emplace_back(curves);
         }
 
         ext::shared_ptr<Pool> thePool = ext::make_shared<Pool>();
@@ -296,21 +291,6 @@ int main(int, char* []) {
                 cout << endl;
         }
 
-
-
-        Real seconds  = timer.elapsed();
-        Integer hours = Integer(seconds/3600);
-        seconds -= hours * 3600;
-        Integer minutes = Integer(seconds/60);
-        seconds -= minutes * 60;
-        cout << "Run completed in ";
-        if (hours > 0)
-            cout << hours << " h ";
-        if (hours > 0 || minutes > 0)
-            cout << minutes << " m ";
-        cout << fixed << setprecision(0)
-             << seconds << " s" << endl;
-
         return 0;
     } catch (exception& e) {
         cerr << e.what() << endl;
