@@ -21,30 +21,21 @@
     \brief
 */
 
-#include <ql/cashflows/conundrumpricer.hpp>
-#include <ql/math/integrals/kronrodintegral.hpp>
-#include <ql/math/distributions/normaldistribution.hpp>
-#include <ql/pricingengines/blackformula.hpp>
-#include <ql/math/solvers1d/newton.hpp>
-#include <ql/termstructures/volatility/smilesection.hpp>
 #include <ql/cashflows/cmscoupon.hpp>
-#include <ql/termstructures/yieldtermstructure.hpp>
-#include <ql/quotes/simplequote.hpp>
-#include <ql/indexes/swapindex.hpp>
+#include <ql/cashflows/conundrumpricer.hpp>
+#include <ql/functional.hpp>
 #include <ql/indexes/interestrateindex.hpp>
-#include <ql/time/schedule.hpp>
+#include <ql/indexes/swapindex.hpp>
 #include <ql/instruments/vanillaswap.hpp>
-
-#if defined(__GNUC__) && (((__GNUC__ == 4) && (__GNUC_MINOR__ >= 8)) || (__GNUC__ > 4))
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wunused-local-typedefs"
-#endif
-
-#include <boost/bind.hpp>
-
-#if defined(__GNUC__) && (((__GNUC__ == 4) && (__GNUC_MINOR__ >= 8)) || (__GNUC__ > 4))
-#pragma GCC diagnostic pop
-#endif
+#include <ql/math/distributions/normaldistribution.hpp>
+#include <ql/math/integrals/kronrodintegral.hpp>
+#include <ql/math/solvers1d/newton.hpp>
+#include <ql/pricingengines/blackformula.hpp>
+#include <ql/quotes/simplequote.hpp>
+#include <ql/termstructures/volatility/smilesection.hpp>
+#include <ql/termstructures/yieldtermstructure.hpp>
+#include <ql/time/schedule.hpp>
+#include <utility>
 
 namespace QuantLib {
 
@@ -77,15 +68,12 @@ namespace QuantLib {
 //===========================================================================//
 //                             HaganPricer                               //
 //===========================================================================//
-    HaganPricer::HaganPricer(
-                const Handle<SwaptionVolatilityStructure>& swaptionVol,
-                GFunctionFactory::YieldCurveModel modelOfYieldCurve,
-                const Handle<Quote>& meanReversion)
-    : CmsCouponPricer(swaptionVol),
-      modelOfYieldCurve_(modelOfYieldCurve),
-      cutoffForCaplet_(2), cutoffForFloorlet_(0),
-      meanReversion_(meanReversion) {
-          registerWith(meanReversion_);
+    HaganPricer::HaganPricer(const Handle<SwaptionVolatilityStructure>& swaptionVol,
+                             GFunctionFactory::YieldCurveModel modelOfYieldCurve,
+                             Handle<Quote> meanReversion)
+    : CmsCouponPricer(swaptionVol), modelOfYieldCurve_(modelOfYieldCurve), cutoffForCaplet_(2),
+      cutoffForFloorlet_(0), meanReversion_(std::move(meanReversion)) {
+        registerWith(meanReversion_);
     }
 
     void HaganPricer::initialize(const FloatingRateCoupon& coupon){
@@ -216,7 +204,7 @@ namespace QuantLib {
 
         class VariableChange {
           public:
-            VariableChange(boost::function<Real (Real)>& f,
+            VariableChange(ext::function<Real (Real)>& f,
                            Real a, Real b, Size k)
             : a_(a), width_(b-a), f_(f), k_(k) {}
             Real value(Real x) const {
@@ -230,13 +218,13 @@ namespace QuantLib {
             }
           private:
             Real a_, width_;
-            boost::function<Real (Real)> f_;
+            ext::function<Real (Real)> f_;
             Size k_;
         };
 
         class Spy {
           public:
-            explicit Spy(boost::function<Real (Real)> f) : f_(f) {}
+            explicit Spy(ext::function<Real(Real)> f) : f_(std::move(f)) {}
             Real value(Real x){
                 abscissas.push_back(x);
                 Real value = f_(x);
@@ -244,7 +232,7 @@ namespace QuantLib {
                 return value;
             }
           private:
-            boost::function<Real (Real)> f_;
+            ext::function<Real (Real)> f_;
             std::vector<Real> abscissas;
             std::vector<Real> functionValues;
         };
@@ -269,8 +257,8 @@ namespace QuantLib {
 
     }
 
-    Real NumericHaganPricer::integrate(Real a,
-        Real b, const ConundrumIntegrand& integrand) const {
+    Real NumericHaganPricer::integrate(Real a, Real b, const ConundrumIntegrand& integrand) const {
+
             Real result =.0;
             //double abserr =.0;
             //double alpha = 1.0;
@@ -291,7 +279,7 @@ namespace QuantLib {
                 if (b > a)
                     upperBoundary = std::min(upperBoundary, b);
 
-                boost::function<Real (Real)> f;
+                ext::function<Real (Real)> f;
                 GaussKronrodNonAdaptive
                     gaussKronrodNonAdaptive(precision_, 1000000, 1.0);
                 // if the integration intervall is wide enough we use the
@@ -299,12 +287,12 @@ namespace QuantLib {
                 upperBoundary = std::max(a,std::min(upperBoundary, hardUpperLimit_));
                 if (upperBoundary > 2*a){
                     Size k = 3;
-                    boost::function<Real (Real)> temp = boost::ref(integrand);
+                    ext::function<Real (Real)> temp = ext::cref(integrand);
                     VariableChange variableChange(temp, a, upperBoundary, k);
-                    f = boost::bind(&VariableChange::value, &variableChange, _1);
+                    f = [&](Real _x) { return variableChange.value(_x); };
                     result = gaussKronrodNonAdaptive(f, .0, 1.0);
                 } else {
-                    f = boost::ref(integrand);
+                    f = ext::cref(integrand);
                     result = gaussKronrodNonAdaptive(f, a, upperBoundary);
                 }
 
@@ -401,19 +389,18 @@ namespace QuantLib {
 //===========================================================================//
 
     NumericHaganPricer::ConundrumIntegrand::ConundrumIntegrand(
-        const ext::shared_ptr<VanillaOptionPricer>& o,
+        ext::shared_ptr<VanillaOptionPricer> o,
         const ext::shared_ptr<YieldTermStructure>&,
-        const ext::shared_ptr<GFunction>& gFunction,
+        ext::shared_ptr<GFunction> gFunction,
         Date fixingDate,
         Date paymentDate,
         Real annuity,
         Real forwardValue,
         Real strike,
         Option::Type optionType)
-    : vanillaOptionPricer_(o), forwardValue_(forwardValue), annuity_(annuity),
-      fixingDate_(fixingDate), paymentDate_(paymentDate), strike_(strike),
-      optionType_(optionType),
-      gFunction_(gFunction) {}
+    : vanillaOptionPricer_(std::move(o)), forwardValue_(forwardValue), annuity_(annuity),
+      fixingDate_(fixingDate), paymentDate_(paymentDate), strike_(strike), optionType_(optionType),
+      gFunction_(std::move(gFunction)) {}
 
     void NumericHaganPricer::ConundrumIntegrand::setStrike(Real strike) {
         strike_ = strike;
@@ -605,16 +592,16 @@ namespace QuantLib {
         Size n = fixedLeg.size();
         accruals_.reserve(n);
         for (Size i=0; i<n; ++i) {
-            ext::shared_ptr<Coupon> coupon =
+            ext::shared_ptr<Coupon> cpn =
                 ext::dynamic_pointer_cast<Coupon>(fixedLeg[i]);
-            accruals_.push_back(coupon->accrualPeriod());
+            accruals_.push_back(cpn->accrualPeriod());
         }
     }
 
     Real GFunctionFactory::GFunctionExactYield::operator()(Real x) {
         Real product = 1.;
-        for(Size i=0; i<accruals_.size(); i++) {
-            product *= 1./(1.+ accruals_[i]*x);
+        for (double accrual : accruals_) {
+            product *= 1. / (1. + accrual * x);
         }
         return x*std::pow(1.+ accruals_[0]*x,-delta_)*(1./(1.-product));
     }
@@ -624,11 +611,11 @@ namespace QuantLib {
         Real derC = 0.;
         std::vector<Real> b;
         b.reserve(accruals_.size());
-        for (Size i=0; i<accruals_.size(); i++) {
-            Real temp = 1.0/(1.0+ accruals_[i]*x);
+        for (double accrual : accruals_) {
+            Real temp = 1.0 / (1.0 + accrual * x);
             b.push_back(temp);
             c *= temp;
-            derC += accruals_[i]*temp;
+            derC += accrual * temp;
         }
         c += 1.;
         c = 1./c;
@@ -646,12 +633,12 @@ namespace QuantLib {
         Real sumOfSquare = 0.;
         std::vector<Real> b;
         b.reserve(accruals_.size());
-        for(Size i=0; i<accruals_.size(); i++) {
-            Real temp = 1.0/(1.0+ accruals_[i]*x);
+        for (double accrual : accruals_) {
+            Real temp = 1.0 / (1.0 + accrual * x);
             b.push_back(temp);
             c *= temp;
-            sum += accruals_[i]*temp;
-            sumOfSquare += std::pow(accruals_[i]*temp, 2.0);
+            sum += accrual * temp;
+            sumOfSquare += std::pow(accrual * temp, 2.0);
         }
         c += 1.;
         c = 1./c;
@@ -675,11 +662,10 @@ namespace QuantLib {
 //                            GFunctionWithShifts                            //
 //===========================================================================//
 
-    GFunctionFactory::GFunctionWithShifts::GFunctionWithShifts(
-                    const CmsCoupon& coupon,
-                    const Handle<Quote>& meanReversion)
-    : meanReversion_(meanReversion), calibratedShift_(0.03),
-      tmpRs_(10000000.0), accuracy_( 1.0e-14) {
+    GFunctionFactory::GFunctionWithShifts::GFunctionWithShifts(const CmsCoupon& coupon,
+                                                               Handle<Quote> meanReversion)
+    : meanReversion_(std::move(meanReversion)), calibratedShift_(0.03), tmpRs_(10000000.0),
+      accuracy_(1.0e-14) {
 
         const ext::shared_ptr<SwapIndex>& swapIndex = coupon.swapIndex();
         const ext::shared_ptr<VanillaSwap>& swap = swapIndex->underlyingSwap(coupon.fixingDate());
@@ -708,10 +694,10 @@ namespace QuantLib {
         shapedSwapPaymentTimes_.reserve(n);
         swapPaymentDiscounts_.reserve(n);
         for(Size i=0; i<n; ++i) {
-            ext::shared_ptr<Coupon> coupon =
+            ext::shared_ptr<Coupon> cpn =
                 ext::dynamic_pointer_cast<Coupon>(fixedLeg[i]);
-            accruals_.push_back(coupon->accrualPeriod());
-            const Date paymentDate(coupon->date());
+            accruals_.push_back(cpn->accrualPeriod());
+            const Date paymentDate(cpn->date());
             const double swapPaymentTime(dc.yearFraction(rateCurve->referenceDate(), paymentDate));
             shapedSwapPaymentTimes_.push_back(shapeOfShift(swapPaymentTime));
             swapPaymentDiscounts_.push_back(rateCurve->discount(paymentDate));
