@@ -27,9 +27,10 @@
 #include <ql/math/interpolation.hpp>
 #include <ql/models/shortrate/onefactormodels/gaussian1dmodel.hpp>
 #include <ql/processes/mfstateprocess.hpp>
+#include <ql/termstructures/volatility/optionlet/optionletvolatilitystructure.hpp>
 #include <ql/termstructures/volatility/smilesection.hpp>
 #include <ql/termstructures/volatility/swaption/swaptionvolstructure.hpp>
-#include <ql/termstructures/volatility/optionlet/optionletvolatilitystructure.hpp>
+#include <utility>
 
 namespace QuantLib {
 
@@ -101,17 +102,14 @@ namespace QuantLib {
 
         class CustomSmileSection : public SmileSection {
         public:
-            virtual Real
-            inverseDigitalCall(const Real price,
-                               const Real discount = 1.0) const = 0;
+          virtual Real inverseDigitalCall(Real price, Real discount = 1.0) const = 0;
         };
 
         class CustomSmileFactory {
         public:
-            virtual ~CustomSmileFactory() {}
-            virtual ext::shared_ptr<CustomSmileSection>
-            smileSection(const ext::shared_ptr<SmileSection>& source,
-                         const Real atm) const = 0;
+          virtual ~CustomSmileFactory() = default;
+          virtual ext::shared_ptr<CustomSmileSection>
+          smileSection(const ext::shared_ptr<SmileSection>& source, Real atm) const = 0;
         };
 
         struct ModelSettings {
@@ -132,25 +130,26 @@ namespace QuantLib {
             };
 
             ModelSettings()
-                : yGridPoints_(64), yStdDevs_(7.0), gaussHermitePoints_(32),
-                  digitalGap_(1E-5), marketRateAccuracy_(1E-7),
-                  lowerRateBound_(0.0), upperRateBound_(2.0),
-                  adjustments_(KahaleSmile | SmileExponentialExtrapolation),
-                  smileMoneynessCheckpoints_(std::vector<Real>()) {}
+            : adjustments_(KahaleSmile | SmileExponentialExtrapolation),
+              smileMoneynessCheckpoints_(std::vector<Real>()) {}
 
-            ModelSettings(Size yGridPoints, Real yStdDevs, Size gaussHermitePoints,
-                          Real digitalGap, Real marketRateAccuracy,
-                          Real lowerRateBound, Real upperRateBound,
+            ModelSettings(Size yGridPoints,
+                          Real yStdDevs,
+                          Size gaussHermitePoints,
+                          Real digitalGap,
+                          Real marketRateAccuracy,
+                          Real lowerRateBound,
+                          Real upperRateBound,
                           int adjustments,
-                          const std::vector<Real>& smileMoneyCheckpoints = std::vector<Real>(),
-                          const ext::shared_ptr<CustomSmileFactory> customSmileFactory =
-                                                       ext::shared_ptr<CustomSmileFactory>())
-                : yGridPoints_(yGridPoints), yStdDevs_(yStdDevs),
-                  gaussHermitePoints_(gaussHermitePoints), digitalGap_(digitalGap),
-                  marketRateAccuracy_(marketRateAccuracy), lowerRateBound_(lowerRateBound),
-                  upperRateBound_(upperRateBound), adjustments_(adjustments),
-                  smileMoneynessCheckpoints_(smileMoneyCheckpoints),
-                  customSmileFactory_(customSmileFactory) {}
+                          std::vector<Real> smileMoneyCheckpoints = std::vector<Real>(),
+                          ext::shared_ptr<CustomSmileFactory> customSmileFactory =
+                              ext::shared_ptr<CustomSmileFactory>())
+            : yGridPoints_(yGridPoints), yStdDevs_(yStdDevs),
+              gaussHermitePoints_(gaussHermitePoints), digitalGap_(digitalGap),
+              marketRateAccuracy_(marketRateAccuracy), lowerRateBound_(lowerRateBound),
+              upperRateBound_(upperRateBound), adjustments_(adjustments),
+              smileMoneynessCheckpoints_(std::move(smileMoneyCheckpoints)),
+              customSmileFactory_(std::move(customSmileFactory)) {}
 
             void validate() {
 
@@ -250,11 +249,11 @@ namespace QuantLib {
                 return *this;
             }
 
-            Size yGridPoints_;
-            Real yStdDevs_;
-            Size gaussHermitePoints_;
-            Real digitalGap_, marketRateAccuracy_;
-            Real lowerRateBound_, upperRateBound_;
+            Size yGridPoints_ = 64;
+            Real yStdDevs_ = 7.0;
+            Size gaussHermitePoints_ = 32;
+            Real digitalGap_ = 1E-5, marketRateAccuracy_ = 1E-7;
+            Real lowerRateBound_ = 0.0, upperRateBound_ = 2.0;
             int adjustments_;
             std::vector<Real> smileMoneynessCheckpoints_;
             ext::shared_ptr<CustomSmileFactory> customSmileFactory_;
@@ -305,27 +304,25 @@ namespace QuantLib {
         };
 
         // Constructor for a swaption smile calibrated model
-        MarkovFunctional(const Handle<YieldTermStructure> &termStructure,
-                         const Real reversion,
-                         const std::vector<Date> &volstepdates,
-                         const std::vector<Real> &volatilities,
-                         const Handle<SwaptionVolatilityStructure> &swaptionVol,
-                         const std::vector<Date> &swaptionExpiries,
-                         const std::vector<Period> &swaptionTenors,
-                         const ext::shared_ptr<SwapIndex> &swapIndexBase,
-                         const MarkovFunctional::ModelSettings &modelSettings =
-                             ModelSettings());
+        MarkovFunctional(const Handle<YieldTermStructure>& termStructure,
+                         Real reversion,
+                         std::vector<Date> volstepdates,
+                         std::vector<Real> volatilities,
+                         const Handle<SwaptionVolatilityStructure>& swaptionVol,
+                         const std::vector<Date>& swaptionExpiries,
+                         const std::vector<Period>& swaptionTenors,
+                         const ext::shared_ptr<SwapIndex>& swapIndexBase,
+                         MarkovFunctional::ModelSettings modelSettings = ModelSettings());
 
         // Constructor for a caplet smile calibrated model
-        MarkovFunctional(const Handle<YieldTermStructure> &termStructure,
-                         const Real reversion,
-                         const std::vector<Date> &volstepdates,
-                         const std::vector<Real> &volatilities,
-                         const Handle<OptionletVolatilityStructure> &capletVol,
-                         const std::vector<Date> &capletExpiries,
-                         const ext::shared_ptr<IborIndex> &iborIndex,
-                         const MarkovFunctional::ModelSettings &modelSettings =
-                             ModelSettings());
+        MarkovFunctional(const Handle<YieldTermStructure>& termStructure,
+                         Real reversion,
+                         std::vector<Date> volstepdates,
+                         std::vector<Real> volatilities,
+                         const Handle<OptionletVolatilityStructure>& capletVol,
+                         const std::vector<Date>& capletExpiries,
+                         ext::shared_ptr<IborIndex> iborIndex,
+                         MarkovFunctional::ModelSettings modelSettings = ModelSettings());
 
         const ModelSettings &modelSettings() const { return modelSettings_; }
         const ModelOutputs &modelOutputs() const;
@@ -335,30 +332,26 @@ namespace QuantLib {
 
         const Array &volatility() const { return sigma_.params(); }
 
-        void calibrate(
-            const std::vector<ext::shared_ptr<CalibrationHelper> > &helpers,
-            OptimizationMethod &method, const EndCriteria &endCriteria,
-            const Constraint &constraint = Constraint(),
-            const std::vector<Real> &weights = std::vector<Real>(),
-            const std::vector<bool> &fixParameters = std::vector<bool>()) {
+        // VC++ warns when overriding a deprecated method
+        QL_DEPRECATED_DISABLE_WARNING
+        void calibrate(const std::vector<ext::shared_ptr<CalibrationHelper> >& helpers,
+                       OptimizationMethod& method,
+                       const EndCriteria& endCriteria,
+                       const Constraint& constraint = Constraint(),
+                       const std::vector<Real>& weights = std::vector<Real>(),
+                       const std::vector<bool>& fixParameters = std::vector<bool>()) override {
 
-            CalibratedModel::calibrate(helpers, method, endCriteria, constraint,
-                                       weights, fixParameters.size() == 0
-                                                    ? FixedFirstVolatility()
-                                                    : fixParameters);
+            CalibratedModel::calibrate(helpers, method, endCriteria, constraint, weights,
+                                       fixParameters.empty() ? FixedFirstVolatility() :
+                                                               fixParameters);
         }
 
-        // VC++ warns when overriding a deprecated method
-        #if defined(QL_PATCH_MSVC)
-        #pragma warning(push)
-        #pragma warning(disable:4996)
-        #endif
-        void calibrate(
-            const std::vector<ext::shared_ptr<BlackCalibrationHelper> > &helpers,
-            OptimizationMethod &method, const EndCriteria &endCriteria,
-            const Constraint &constraint = Constraint(),
-            const std::vector<Real> &weights = std::vector<Real>(),
-            const std::vector<bool> &fixParameters = std::vector<bool>()) {
+        void calibrate(const std::vector<ext::shared_ptr<BlackCalibrationHelper> >& helpers,
+                       OptimizationMethod& method,
+                       const EndCriteria& endCriteria,
+                       const Constraint& constraint = Constraint(),
+                       const std::vector<Real>& weights = std::vector<Real>(),
+                       const std::vector<bool>& fixParameters = std::vector<bool>()) override {
 
             std::vector<ext::shared_ptr<CalibrationHelper> > tmp(helpers.size());
             for (Size i=0; i<helpers.size(); ++i)
@@ -366,16 +359,12 @@ namespace QuantLib {
 
             calibrate(tmp, method, endCriteria, constraint, weights, fixParameters);
         }
-        #if defined(QL_PATCH_MSVC)
-        #pragma warning(pop)
-        #endif
+        QL_DEPRECATED_ENABLE_WARNING
 
-        void update() {
-            LazyObject::update();
-        }
+        void update() override { LazyObject::update(); }
 
         // returns the indices of the af region from the last smile update
-        const std::vector<std::pair<Size,Size> > arbitrageIndices() const {
+        std::vector<std::pair<Size, Size> > arbitrageIndices() const {
             calculate();
             return arbitrageIndices_;
         }
@@ -388,14 +377,12 @@ namespace QuantLib {
         }
 
       protected:
+        Real numeraireImpl(Time t, Real y, const Handle<YieldTermStructure>& yts) const override;
 
-        Real numeraireImpl(const Time t, const Real y,
-                           const Handle<YieldTermStructure> &yts) const;
+        Real
+        zerobondImpl(Time T, Time t, Real y, const Handle<YieldTermStructure>& yts) const override;
 
-        Real zerobondImpl(const Time T, const Time t, const Real y,
-                          const Handle<YieldTermStructure> &yts) const;
-
-        void generateArguments() {
+        void generateArguments() override {
             // if calculate triggers performCalculations, updateNumeraireTabulations
             // is called twice. If we can not check the lazy object status this seem
             // hard to avoid though.
@@ -404,7 +391,7 @@ namespace QuantLib {
             notifyObservers();
         }
 
-        void performCalculations() const {
+        void performCalculations() const override {
             Gaussian1dModel::performCalculations();
             updateTimes();
             updateSmiles();
@@ -431,24 +418,21 @@ namespace QuantLib {
                                           const Period &tenor);
         void makeCapletCalibrationPoint(const Date &expiry);
 
-        Real marketSwapRate(const Date &expiry, const CalibrationPoint &p,
-                            const Real digitalPrice,
-                            const Real guess = 0.03,
-                            const Real shift = 0.0) const;
-        Real marketDigitalPrice(const Date &expiry,
-                                const CalibrationPoint &p,
-                                const Option::Type &type,
-                                const Real strike) const;
+        Real marketSwapRate(const Date& expiry,
+                            const CalibrationPoint& p,
+                            Real digitalPrice,
+                            Real guess = 0.03,
+                            Real shift = 0.0) const;
+        Real marketDigitalPrice(const Date& expiry,
+                                const CalibrationPoint& p,
+                                const Option::Type& type,
+                                Real strike) const;
 
-        const Disposable<Array>
-        deflatedZerobondArray(const Time T, const Time t, const Array &y) const;
-        const Disposable<Array> numeraireArray(const Time t,
-                                               const Array &y) const;
-        const Disposable<Array> zerobondArray(const Time T, const Time t,
-                                              const Array &y) const;
+        Disposable<Array> deflatedZerobondArray(Time T, Time t, const Array& y) const;
+        Disposable<Array> numeraireArray(Time t, const Array& y) const;
+        Disposable<Array> zerobondArray(Time T, Time t, const Array& y) const;
 
-        Real deflatedZerobond(const Time T, const Time t = 0.0,
-                              const Real y = 0.0) const;
+        Real deflatedZerobond(Time T, Time t = 0.0, Real y = 0.0) const;
 
         // the following methods (tagged internal) are indended only to produce
         // the volatility diagnostics in the model outputs
@@ -457,39 +441,46 @@ namespace QuantLib {
         // for this purpose
 
         Real forwardRateInternal(
-            const Date &fixing, const Date &referenceDate = Null<Date>(),
-            const Real y = 0.0, const bool zeroFixingDays = false,
-            ext::shared_ptr<IborIndex> iborIdx =
-                ext::shared_ptr<IborIndex>()) const;
-
-        Real swapRateInternal(const Date &fixing, const Period &tenor,
-                              const Date &referenceDate = Null<Date>(),
-                              const Real y = 0.0,
-                              const bool zeroFixingDays = false,
-                              ext::shared_ptr<SwapIndex> swapIdx =
-                                        ext::shared_ptr<SwapIndex>()) const;
+            const Date& fixing,
+            const Date& referenceDate = Null<Date>(),
+            Real y = 0.0,
+            bool zeroFixingDays = false,
+            ext::shared_ptr<IborIndex> iborIdx = ext::shared_ptr<IborIndex>()) const;
 
         Real
-        swapAnnuityInternal(const Date &fixing, const Period &tenor,
-                            const Date &referenceDate = Null<Date>(),
-                            const Real y = 0.0,
-                            const bool zeroFixingDays = false,
-                            ext::shared_ptr<SwapIndex> swapIdx =
-                                ext::shared_ptr<SwapIndex>()) const;
+        swapRateInternal(const Date& fixing,
+                         const Period& tenor,
+                         const Date& referenceDate = Null<Date>(),
+                         Real y = 0.0,
+                         bool zeroFixingDays = false,
+                         ext::shared_ptr<SwapIndex> swapIdx = ext::shared_ptr<SwapIndex>()) const;
+
+        Real swapAnnuityInternal(
+            const Date& fixing,
+            const Period& tenor,
+            const Date& referenceDate = Null<Date>(),
+            Real y = 0.0,
+            bool zeroFixingDays = false,
+            ext::shared_ptr<SwapIndex> swapIdx = ext::shared_ptr<SwapIndex>()) const;
 
         Real capletPriceInternal(
-            const Option::Type &type, const Date &expiry, const Rate strike,
-            const Date &referenceDate = Null<Date>(), const Real y = 0.0,
-            const bool zeroFixingDays = false,
-            ext::shared_ptr<IborIndex> iborIdx =
-                ext::shared_ptr<IborIndex>()) const;
+            const Option::Type& type,
+            const Date& expiry,
+            Rate strike,
+            const Date& referenceDate = Null<Date>(),
+            Real y = 0.0,
+            bool zeroFixingDays = false,
+            ext::shared_ptr<IborIndex> iborIdx = ext::shared_ptr<IborIndex>()) const;
 
         Real swaptionPriceInternal(
-            const Option::Type &type, const Date &expiry, const Period &tenor,
-            const Rate strike, const Date &referenceDate = Null<Date>(),
-            const Real y = 0.0, const bool zeroFixingDays = false,
-            ext::shared_ptr<SwapIndex> swapIdx =
-                ext::shared_ptr<SwapIndex>()) const;
+            const Option::Type& type,
+            const Date& expiry,
+            const Period& tenor,
+            Rate strike,
+            const Date& referenceDate = Null<Date>(),
+            Real y = 0.0,
+            bool zeroFixingDays = false,
+            const ext::shared_ptr<SwapIndex>& swapIdx = ext::shared_ptr<SwapIndex>()) const;
 
         class ZeroHelper;
         friend class ZeroHelper;
