@@ -93,12 +93,13 @@ namespace QuantLib {
         return arguments_.swap->type();
     }
 
+    // NOLINTNEXTLINE(readability-const-return-type)
     const Date Gaussian1dNonstandardSwaptionEngine::underlyingLastDate() const {
         return arguments_.fixedPayDates.back();
     }
 
-    const Disposable<Array> Gaussian1dNonstandardSwaptionEngine::initialGuess(
-        const Date &expiry) const {
+    // NOLINTNEXTLINE(readability-const-return-type)
+    const Disposable<Array> Gaussian1dNonstandardSwaptionEngine::initialGuess(const Date &expiry) const {
 
         Size fixedIdx =
             std::upper_bound(arguments_.fixedResetDates.begin(),
@@ -168,7 +169,7 @@ namespace QuantLib {
         // for probability computation
         std::vector<Array> npvp0, npvp1;
         if (probabilities_ != None) {
-            for (Size i = 0; i < static_cast<Size>(idx - minIdxAlive + 2); ++i) {
+            for (int i = 0; i < idx - minIdxAlive + 2; ++i) {
                 Array npvTmp0(2 * integrationPoints_ + 1, 0.0);
                 Array npvTmp1(2 * integrationPoints_ + 1, 0.0);
                 npvp0.push_back(npvTmp0);
@@ -414,7 +415,7 @@ namespace QuantLib {
                     Real rebate = 0.0;
                     Real zSpreadDf = 1.0;
                     Date rebateDate = expiry0;
-                    if (rebatedExercise != NULL) {
+                    if (rebatedExercise != nullptr) {
                         rebate = rebatedExercise->rebate(idx);
                         rebateDate = rebatedExercise->rebatePaymentDate(idx);
                         zSpreadDf =
