@@ -23,19 +23,19 @@
  FOR A PARTICULAR PURPOSE.  See the license for more details.
 */
 
-#include <ql/termstructures/yield/ratehelpers.hpp>
-#include <ql/time/imm.hpp>
-#include <ql/time/asx.hpp>
-#include <ql/time/calendars/unitedstates.hpp>
-#include <ql/time/calendars/jointcalendar.hpp>
+#include <ql/cashflows/iborcoupon.hpp>
+#include <ql/currency.hpp>
+#include <ql/indexes/swapindex.hpp>
 #include <ql/instruments/makevanillaswap.hpp>
 #include <ql/pricingengines/swap/discountingswapengine.hpp>
 #include <ql/quote.hpp>
-#include <ql/currency.hpp>
-#include <ql/indexes/swapindex.hpp>
-#include <ql/cashflows/iborcoupon.hpp>
+#include <ql/termstructures/yield/ratehelpers.hpp>
+#include <ql/time/asx.hpp>
+#include <ql/time/calendars/jointcalendar.hpp>
+#include <ql/time/calendars/unitedstates.hpp>
 #include <ql/time/imm.hpp>
 #include <ql/utilities/null_deleter.hpp>
+#include <utility>
 
 namespace QuantLib {
 
@@ -46,9 +46,9 @@ namespace QuantLib {
                                          BusinessDayConvention convention,
                                          bool endOfMonth,
                                          const DayCounter& dayCounter,
-                                         const Handle<Quote>& convAdj,
+                                         Handle<Quote> convAdj,
                                          Futures::Type type)
-    : RateHelper(price), convAdj_(convAdj) {
+    : RateHelper(price), convAdj_(std::move(convAdj)) {
         switch (type) {
           case Futures::IMM:
             QL_REQUIRE(IMM::isIMMdate(iborStartDate, false),
@@ -105,9 +105,9 @@ namespace QuantLib {
                                          const Date& iborStartDate,
                                          const Date& iborEndDate,
                                          const DayCounter& dayCounter,
-                                         const Handle<Quote>& convAdj,
+                                         Handle<Quote> convAdj,
                                          Futures::Type type)
-    : RateHelper(price), convAdj_(convAdj) {
+    : RateHelper(price), convAdj_(std::move(convAdj)) {
         switch (type) {
           case Futures::IMM:
             QL_REQUIRE(IMM::isIMMdate(iborStartDate, false),
@@ -264,7 +264,7 @@ namespace QuantLib {
     }
 
     Real FuturesRateHelper::impliedQuote() const {
-        QL_REQUIRE(termStructure_ != 0, "term structure not set");
+        QL_REQUIRE(termStructure_ != nullptr, "term structure not set");
         Rate forwardRate = (termStructure_->discount(earliestDate_) /
             termStructure_->discount(maturityDate_) - 1.0) / yearFraction_;
         Rate convAdj = convAdj_.empty() ? 0.0 : convAdj_->value();
@@ -280,9 +280,8 @@ namespace QuantLib {
     }
 
     void FuturesRateHelper::accept(AcyclicVisitor& v) {
-        Visitor<FuturesRateHelper>* v1 =
-            dynamic_cast<Visitor<FuturesRateHelper>*>(&v);
-        if (v1 != 0)
+        auto* v1 = dynamic_cast<Visitor<FuturesRateHelper>*>(&v);
+        if (v1 != nullptr)
             v1->visit(*this);
         else
             RateHelper::accept(v);
@@ -333,7 +332,7 @@ namespace QuantLib {
     }
 
     Real DepositRateHelper::impliedQuote() const {
-        QL_REQUIRE(termStructure_ != 0, "term structure not set");
+        QL_REQUIRE(termStructure_ != nullptr, "term structure not set");
         // the forecast fixing flag is set to true because
         // we do not want to take fixing into account
         return iborIndex_->fixing(fixingDate_, true);
@@ -362,9 +361,8 @@ namespace QuantLib {
     }
 
     void DepositRateHelper::accept(AcyclicVisitor& v) {
-        Visitor<DepositRateHelper>* v1 =
-            dynamic_cast<Visitor<DepositRateHelper>*>(&v);
-        if (v1 != 0)
+        auto* v1 = dynamic_cast<Visitor<DepositRateHelper>*>(&v);
+        if (v1 != nullptr)
             v1->visit(*this);
         else
             RateHelper::accept(v);
@@ -582,7 +580,7 @@ namespace QuantLib {
     }
 
     Real FraRateHelper::impliedQuote() const {
-        QL_REQUIRE(termStructure_ != 0, "term structure not set");
+        QL_REQUIRE(termStructure_ != nullptr, "term structure not set");
         if (useIndexedCoupon_)
             return iborIndex_->fixing(fixingDate_, true);
         else
@@ -620,7 +618,7 @@ namespace QuantLib {
             iborIndex_->fixingCalendar().adjust(evaluationDate_);
         Date spotDate = iborIndex_->fixingCalendar().advance(
             referenceDate, iborIndex_->fixingDays()*Days);
-        if(periodToStart_) {
+        if (periodToStart_) { // NOLINT(readability-implicit-bool-conversion)
             earliestDate_ = iborIndex_->fixingCalendar().advance(
                 spotDate, *periodToStart_, iborIndex_->businessDayConvention(),
                 iborIndex_->endOfMonth());
@@ -628,7 +626,7 @@ namespace QuantLib {
             maturityDate_ = iborIndex_->fixingCalendar().advance(
                 spotDate, *periodToStart_ + iborIndex_->tenor(), iborIndex_->businessDayConvention(),
                 iborIndex_->endOfMonth());
-        } else if (immOffsetStart_ && immOffsetEnd_) {
+        } else if ((immOffsetStart_) && (immOffsetEnd_)) { // NOLINT(readability-implicit-bool-conversion)
             earliestDate_ = iborIndex_->fixingCalendar().adjust(nthImmDate(spotDate, *immOffsetStart_));
             maturityDate_ = iborIndex_->fixingCalendar().adjust(nthImmDate(spotDate, *immOffsetEnd_));
         } else {
@@ -671,9 +669,8 @@ namespace QuantLib {
     }
 
     void FraRateHelper::accept(AcyclicVisitor& v) {
-        Visitor<FraRateHelper>* v1 =
-            dynamic_cast<Visitor<FraRateHelper>*>(&v);
-        if (v1 != 0)
+        auto* v1 = dynamic_cast<Visitor<FraRateHelper>*>(&v);
+        if (v1 != nullptr)
             v1->visit(*this);
         else
             RateHelper::accept(v);
@@ -682,21 +679,18 @@ namespace QuantLib {
 
     SwapRateHelper::SwapRateHelper(const Handle<Quote>& rate,
                                    const ext::shared_ptr<SwapIndex>& swapIndex,
-                                   const Handle<Quote>& spread,
+                                   Handle<Quote> spread,
                                    const Period& fwdStart,
-                                   const Handle<YieldTermStructure>& discount,
+                                   Handle<YieldTermStructure> discount,
                                    Pillar::Choice pillarChoice,
                                    Date customPillarDate,
                                    bool endOfMonth)
-    : RelativeDateRateHelper(rate),
-      settlementDays_(swapIndex->fixingDays()),
-      tenor_(swapIndex->tenor()), pillarChoice_(pillarChoice),
-      calendar_(swapIndex->fixingCalendar()),
+    : RelativeDateRateHelper(rate), settlementDays_(Null<Natural>()), tenor_(swapIndex->tenor()),
+      pillarChoice_(pillarChoice), calendar_(swapIndex->fixingCalendar()),
       fixedConvention_(swapIndex->fixedLegConvention()),
       fixedFrequency_(swapIndex->fixedLegTenor().frequency()),
-      fixedDayCount_(swapIndex->dayCounter()),
-      spread_(spread), endOfMonth_(endOfMonth),
-      fwdStart_(fwdStart), discountHandle_(discount) {
+      fixedDayCount_(swapIndex->dayCounter()), spread_(std::move(spread)), endOfMonth_(endOfMonth),
+      fwdStart_(fwdStart), discountHandle_(std::move(discount)) {
         // take fixing into account
         iborIndex_ = swapIndex->iborIndex()->clone(termStructureHandle_);
         // We want to be notified of changes of fixings, but we don't
@@ -714,30 +708,23 @@ namespace QuantLib {
 
     SwapRateHelper::SwapRateHelper(const Handle<Quote>& rate,
                                    const Period& tenor,
-                                   const Calendar& calendar,
+                                   Calendar calendar,
                                    Frequency fixedFrequency,
                                    BusinessDayConvention fixedConvention,
-                                   const DayCounter& fixedDayCount,
+                                   DayCounter fixedDayCount,
                                    const ext::shared_ptr<IborIndex>& iborIndex,
-                                   const Handle<Quote>& spread,
+                                   Handle<Quote> spread,
                                    const Period& fwdStart,
-                                   const Handle<YieldTermStructure>& discount,
+                                   Handle<YieldTermStructure> discount,
                                    Natural settlementDays,
                                    Pillar::Choice pillarChoice,
                                    Date customPillarDate,
                                    bool endOfMonth)
-    : RelativeDateRateHelper(rate),
-      settlementDays_(settlementDays),
-      tenor_(tenor), pillarChoice_(pillarChoice),
-      calendar_(calendar),
-      fixedConvention_(fixedConvention),
-      fixedFrequency_(fixedFrequency),
-      fixedDayCount_(fixedDayCount),
-      spread_(spread), endOfMonth_(endOfMonth),
-      fwdStart_(fwdStart), discountHandle_(discount) {
-
-        if (settlementDays_==Null<Natural>())
-            settlementDays_ = iborIndex->fixingDays();
+    : RelativeDateRateHelper(rate), settlementDays_(settlementDays), tenor_(tenor),
+      pillarChoice_(pillarChoice), calendar_(std::move(calendar)),
+      fixedConvention_(fixedConvention), fixedFrequency_(fixedFrequency),
+      fixedDayCount_(std::move(fixedDayCount)), spread_(std::move(spread)), endOfMonth_(endOfMonth),
+      fwdStart_(fwdStart), discountHandle_(std::move(discount)) {
 
         // take fixing into account
         iborIndex_ = iborIndex->clone(termStructureHandle_);
@@ -756,21 +743,18 @@ namespace QuantLib {
 
     SwapRateHelper::SwapRateHelper(Rate rate,
                                    const ext::shared_ptr<SwapIndex>& swapIndex,
-                                   const Handle<Quote>& spread,
+                                   Handle<Quote> spread,
                                    const Period& fwdStart,
-                                   const Handle<YieldTermStructure>& discount,
+                                   Handle<YieldTermStructure> discount,
                                    Pillar::Choice pillarChoice,
                                    Date customPillarDate,
                                    bool endOfMonth)
-    : RelativeDateRateHelper(rate),
-      settlementDays_(swapIndex->fixingDays()),
-      tenor_(swapIndex->tenor()), pillarChoice_(pillarChoice),
-      calendar_(swapIndex->fixingCalendar()),
+    : RelativeDateRateHelper(rate), settlementDays_(Null<Natural>()), tenor_(swapIndex->tenor()),
+      pillarChoice_(pillarChoice), calendar_(swapIndex->fixingCalendar()),
       fixedConvention_(swapIndex->fixedLegConvention()),
       fixedFrequency_(swapIndex->fixedLegTenor().frequency()),
-      fixedDayCount_(swapIndex->dayCounter()),
-      spread_(spread), endOfMonth_(endOfMonth),
-      fwdStart_(fwdStart), discountHandle_(discount) {
+      fixedDayCount_(swapIndex->dayCounter()), spread_(std::move(spread)), endOfMonth_(endOfMonth),
+      fwdStart_(fwdStart), discountHandle_(std::move(discount)) {
         // take fixing into account
         iborIndex_ = swapIndex->iborIndex()->clone(termStructureHandle_);
         // We want to be notified of changes of fixings, but we don't
@@ -788,30 +772,23 @@ namespace QuantLib {
 
     SwapRateHelper::SwapRateHelper(Rate rate,
                                    const Period& tenor,
-                                   const Calendar& calendar,
+                                   Calendar calendar,
                                    Frequency fixedFrequency,
                                    BusinessDayConvention fixedConvention,
-                                   const DayCounter& fixedDayCount,
+                                   DayCounter fixedDayCount,
                                    const ext::shared_ptr<IborIndex>& iborIndex,
-                                   const Handle<Quote>& spread,
+                                   Handle<Quote> spread,
                                    const Period& fwdStart,
-                                   const Handle<YieldTermStructure>& discount,
+                                   Handle<YieldTermStructure> discount,
                                    Natural settlementDays,
                                    Pillar::Choice pillarChoice,
                                    Date customPillarDate,
                                    bool endOfMonth)
-    : RelativeDateRateHelper(rate),
-      settlementDays_(settlementDays),
-      tenor_(tenor), pillarChoice_(pillarChoice),
-      calendar_(calendar),
-      fixedConvention_(fixedConvention),
-      fixedFrequency_(fixedFrequency),
-      fixedDayCount_(fixedDayCount),
-      spread_(spread), endOfMonth_(endOfMonth),
-      fwdStart_(fwdStart), discountHandle_(discount) {
-
-        if (settlementDays_==Null<Natural>())
-            settlementDays_ = iborIndex->fixingDays();
+    : RelativeDateRateHelper(rate), settlementDays_(settlementDays), tenor_(tenor),
+      pillarChoice_(pillarChoice), calendar_(std::move(calendar)),
+      fixedConvention_(fixedConvention), fixedFrequency_(fixedFrequency),
+      fixedDayCount_(std::move(fixedDayCount)), spread_(std::move(spread)), endOfMonth_(endOfMonth),
+      fwdStart_(fwdStart), discountHandle_(std::move(discount)) {
 
         // take fixing into account
         iborIndex_ = iborIndex->clone(termStructureHandle_);
@@ -896,7 +873,7 @@ namespace QuantLib {
     }
 
     Real SwapRateHelper::impliedQuote() const {
-        QL_REQUIRE(termStructure_ != 0, "term structure not set");
+        QL_REQUIRE(termStructure_ != nullptr, "term structure not set");
         // we didn't register as observers - force calculation
         swap_->recalculate();
         // weak implementation... to be improved
@@ -910,34 +887,28 @@ namespace QuantLib {
     }
 
     void SwapRateHelper::accept(AcyclicVisitor& v) {
-        Visitor<SwapRateHelper>* v1 =
-            dynamic_cast<Visitor<SwapRateHelper>*>(&v);
-        if (v1 != 0)
+        auto* v1 = dynamic_cast<Visitor<SwapRateHelper>*>(&v);
+        if (v1 != nullptr)
             v1->visit(*this);
         else
             RateHelper::accept(v);
     }
 
-    BMASwapRateHelper::BMASwapRateHelper(
-                          const Handle<Quote>& liborFraction,
-                          const Period& tenor,
-                          Natural settlementDays,
-                          const Calendar& calendar,
-                          // bma leg
-                          const Period& bmaPeriod,
-                          BusinessDayConvention bmaConvention,
-                          const DayCounter& bmaDayCount,
-                          const ext::shared_ptr<BMAIndex>& bmaIndex,
-                          // libor leg
-                          const ext::shared_ptr<IborIndex>& iborIndex)
-    : RelativeDateRateHelper(liborFraction),
-      tenor_(tenor), settlementDays_(settlementDays),
-      calendar_(calendar),
-      bmaPeriod_(bmaPeriod),
-      bmaConvention_(bmaConvention),
-      bmaDayCount_(bmaDayCount),
-      bmaIndex_(bmaIndex),
-      iborIndex_(iborIndex) {
+    BMASwapRateHelper::BMASwapRateHelper(const Handle<Quote>& liborFraction,
+                                         const Period& tenor,
+                                         Natural settlementDays,
+                                         Calendar calendar,
+                                         // bma leg
+                                         const Period& bmaPeriod,
+                                         BusinessDayConvention bmaConvention,
+                                         DayCounter bmaDayCount,
+                                         ext::shared_ptr<BMAIndex> bmaIndex,
+                                         // libor leg
+                                         ext::shared_ptr<IborIndex> iborIndex)
+    : RelativeDateRateHelper(liborFraction), tenor_(tenor), settlementDays_(settlementDays),
+      calendar_(std::move(calendar)), bmaPeriod_(bmaPeriod), bmaConvention_(bmaConvention),
+      bmaDayCount_(std::move(bmaDayCount)), bmaIndex_(std::move(bmaIndex)),
+      iborIndex_(std::move(iborIndex)) {
         registerWith(iborIndex_);
         registerWith(bmaIndex_);
         initializeDates();
@@ -1005,36 +976,34 @@ namespace QuantLib {
     }
 
     Real BMASwapRateHelper::impliedQuote() const {
-        QL_REQUIRE(termStructure_ != 0, "term structure not set");
+        QL_REQUIRE(termStructure_ != nullptr, "term structure not set");
         // we didn't register as observers - force calculation
         swap_->recalculate();
         return swap_->fairLiborFraction();
     }
 
     void BMASwapRateHelper::accept(AcyclicVisitor& v) {
-        Visitor<BMASwapRateHelper>* v1 =
-            dynamic_cast<Visitor<BMASwapRateHelper>*>(&v);
-        if (v1 != 0)
+        auto* v1 = dynamic_cast<Visitor<BMASwapRateHelper>*>(&v);
+        if (v1 != nullptr)
             v1->visit(*this);
         else
             RateHelper::accept(v);
     }
 
     FxSwapRateHelper::FxSwapRateHelper(const Handle<Quote>& fwdPoint,
-                                       const Handle<Quote>& spotFx,
+                                       Handle<Quote> spotFx,
                                        const Period& tenor,
                                        Natural fixingDays,
-                                       const Calendar& calendar,
+                                       Calendar calendar,
                                        BusinessDayConvention convention,
                                        bool endOfMonth,
                                        bool isFxBaseCurrencyCollateralCurrency,
-                                       const Handle<YieldTermStructure>& coll,
-                                       const Calendar& tradingCalendar)
-    : RelativeDateRateHelper(fwdPoint), spot_(spotFx), tenor_(tenor),
-      fixingDays_(fixingDays), cal_(calendar), conv_(convention),
-      eom_(endOfMonth),
+                                       Handle<YieldTermStructure> coll,
+                                       Calendar tradingCalendar)
+    : RelativeDateRateHelper(fwdPoint), spot_(std::move(spotFx)), tenor_(tenor),
+      fixingDays_(fixingDays), cal_(std::move(calendar)), conv_(convention), eom_(endOfMonth),
       isFxBaseCurrencyCollateralCurrency_(isFxBaseCurrencyCollateralCurrency),
-      collHandle_(coll), tradingCalendar_(tradingCalendar) {
+      collHandle_(std::move(coll)), tradingCalendar_(std::move(tradingCalendar)) {
         registerWith(spot_);
         registerWith(collHandle_);
 
@@ -1063,7 +1032,7 @@ namespace QuantLib {
     }
 
     Real FxSwapRateHelper::impliedQuote() const {
-        QL_REQUIRE(termStructure_ != 0, "term structure not set");
+        QL_REQUIRE(termStructure_ != nullptr, "term structure not set");
 
         QL_REQUIRE(!collHandle_.empty(), "collateral term structure not set");
 
@@ -1095,9 +1064,8 @@ namespace QuantLib {
     }
 
     void FxSwapRateHelper::accept(AcyclicVisitor& v) {
-        Visitor<FxSwapRateHelper>* v1 =
-            dynamic_cast<Visitor<FxSwapRateHelper>*>(&v);
-        if (v1 != 0)
+        auto* v1 = dynamic_cast<Visitor<FxSwapRateHelper>*>(&v);
+        if (v1 != nullptr)
             v1->visit(*this);
         else
             RateHelper::accept(v);
