@@ -4,6 +4,8 @@
  Copyright (C) 2000, 2001, 2002, 2003 RiskMap srl
  Copyright (C) 2003, 2004, 2005, 2006, 2007 StatPro Italia srl
  Copyright (C) 2006 Piter Dias
+ Copyright (C) 2020 Leonardo Arcari
+ Copyright (C) 2020 Kline s.r.l.
 
  This file is part of QuantLib, a free-software/open-source library
  for financial quantitative analysts and developers - http://quantlib.org/
@@ -61,7 +63,7 @@ namespace QuantLib {
         //! abstract base class for calendar implementations
         class Impl {
           public:
-            virtual ~Impl() {}
+            virtual ~Impl() = default;
             virtual std::string name() const = 0;
             virtual bool isBusinessDay(const Date&) const = 0;
             virtual bool isWeekend(Weekday) const = 0;
@@ -73,7 +75,7 @@ namespace QuantLib {
             implementation, which is therefore unusable except as a
             placeholder.
         */
-        Calendar() {}
+        Calendar() = default;
         //! \name Calendar interface
         //@{
         //!  Returns whether or not the calendar is initialized
@@ -173,7 +175,7 @@ namespace QuantLib {
         */
         class WesternImpl : public Impl {
           public:
-            bool isWeekend(Weekday) const;
+            bool isWeekend(Weekday) const override;
             //! expressed relative to first day of year
             static Day easterMonday(Year);
         };
@@ -184,7 +186,7 @@ namespace QuantLib {
         */
         class OrthodoxImpl : public Impl {
           public:
-            bool isWeekend(Weekday) const;
+            bool isWeekend(Weekday) const override;
             //! expressed relative to first day of year
             static Day easterMonday(Year);
         };
@@ -216,11 +218,13 @@ namespace QuantLib {
 
     inline const std::set<Date>& Calendar::addedHolidays() const {
         QL_REQUIRE(impl_, "no calendar implementation provided");
+
         return impl_->addedHolidays;
     }
 
     inline const std::set<Date>& Calendar::removedHolidays() const {
         QL_REQUIRE(impl_, "no calendar implementation provided");
+
         return impl_->removedHolidays;
     }
 
@@ -233,9 +237,12 @@ namespace QuantLib {
         const Date& _d = d;
 #endif
 
-        if (impl_->addedHolidays.find(_d) != impl_->addedHolidays.end())
+        if (!impl_->addedHolidays.empty() &&
+            impl_->addedHolidays.find(_d) != impl_->addedHolidays.end())
             return false;
-        if (impl_->removedHolidays.find(_d) != impl_->removedHolidays.end())
+
+        if (!impl_->removedHolidays.empty() &&
+            impl_->removedHolidays.find(_d) != impl_->removedHolidays.end())
             return true;
 
         return impl_->isBusinessDay(_d);
