@@ -19,6 +19,7 @@
 
 #include "creditdefaultswap.hpp"
 #include "utilities.hpp"
+#include <ql/cashflows/iborcoupon.hpp>
 #include <ql/instruments/creditdefaultswap.hpp>
 #include <ql/instruments/makecds.hpp>
 #include <ql/pricingengines/credit/midpointcdsengine.hpp>
@@ -38,12 +39,13 @@
 #include <ql/currencies/america.hpp>
 #include <ql/time/daycounters/actual360.hpp>
 #include <ql/time/daycounters/thirty360.hpp>
-
+#include <map>
 #include <iomanip>
 #include <iostream>
 
 using namespace QuantLib;
 using namespace boost::unit_test_framework;
+using std::map;
 
 void CreditDefaultSwapTest::testCachedValue() {
 
@@ -170,43 +172,45 @@ void CreditDefaultSwapTest::testCachedMarketValue() {
     Date evalDate = Settings::instance().evaluationDate();
     Calendar calendar = UnitedStates();
 
-    std::vector<Date> discountDates;
-    discountDates.push_back(evalDate);
-    discountDates.push_back(calendar.advance(evalDate, 1, Weeks,  ModifiedFollowing));
-    discountDates.push_back(calendar.advance(evalDate, 1, Months, ModifiedFollowing));
-    discountDates.push_back(calendar.advance(evalDate, 2, Months, ModifiedFollowing));
-    discountDates.push_back(calendar.advance(evalDate, 3, Months, ModifiedFollowing));
-    discountDates.push_back(calendar.advance(evalDate, 6, Months, ModifiedFollowing));
-    discountDates.push_back(calendar.advance(evalDate,12, Months, ModifiedFollowing));
-    discountDates.push_back(calendar.advance(evalDate, 2, Years, ModifiedFollowing));
-    discountDates.push_back(calendar.advance(evalDate, 3, Years, ModifiedFollowing));
-    discountDates.push_back(calendar.advance(evalDate, 4, Years, ModifiedFollowing));
-    discountDates.push_back(calendar.advance(evalDate, 5, Years, ModifiedFollowing));
-    discountDates.push_back(calendar.advance(evalDate, 6, Years, ModifiedFollowing));
-    discountDates.push_back(calendar.advance(evalDate, 7, Years, ModifiedFollowing));
-    discountDates.push_back(calendar.advance(evalDate, 8, Years, ModifiedFollowing));
-    discountDates.push_back(calendar.advance(evalDate, 9, Years, ModifiedFollowing));
-    discountDates.push_back(calendar.advance(evalDate,10, Years, ModifiedFollowing));
-    discountDates.push_back(calendar.advance(evalDate,15, Years, ModifiedFollowing));
-
-    std::vector<DiscountFactor> dfs;
-    dfs.push_back(1.0);
-    dfs.push_back(0.9990151375768731);
-    dfs.push_back(0.99570502636871183);
-    dfs.push_back(0.99118260474528685);
-    dfs.push_back(0.98661167950906203);
-    dfs.push_back(0.9732592953359388 );
-    dfs.push_back(0.94724424481038083);
-    dfs.push_back(0.89844996737120875  );
-    dfs.push_back(0.85216647839921411  );
-    dfs.push_back(0.80775477692556874  );
-    dfs.push_back(0.76517289234200347  );
-    dfs.push_back(0.72401019553182933  );
-    dfs.push_back(0.68503909569219212  );
-    dfs.push_back(0.64797499814013748  );
-    dfs.push_back(0.61263171936255534  );
-    dfs.push_back(0.5791942350748791   );
-    dfs.push_back(0.43518868769953606  );
+    std::vector<Date> discountDates = {
+        evalDate,
+        calendar.advance(evalDate, 1, Weeks,  ModifiedFollowing),
+        calendar.advance(evalDate, 1, Months, ModifiedFollowing),
+        calendar.advance(evalDate, 2, Months, ModifiedFollowing),
+        calendar.advance(evalDate, 3, Months, ModifiedFollowing),
+        calendar.advance(evalDate, 6, Months, ModifiedFollowing),
+        calendar.advance(evalDate,12, Months, ModifiedFollowing),
+        calendar.advance(evalDate, 2, Years, ModifiedFollowing),
+        calendar.advance(evalDate, 3, Years, ModifiedFollowing),
+        calendar.advance(evalDate, 4, Years, ModifiedFollowing),
+        calendar.advance(evalDate, 5, Years, ModifiedFollowing),
+        calendar.advance(evalDate, 6, Years, ModifiedFollowing),
+        calendar.advance(evalDate, 7, Years, ModifiedFollowing),
+        calendar.advance(evalDate, 8, Years, ModifiedFollowing),
+        calendar.advance(evalDate, 9, Years, ModifiedFollowing),
+        calendar.advance(evalDate,10, Years, ModifiedFollowing),
+        calendar.advance(evalDate,15, Years, ModifiedFollowing)
+    };
+    
+    std::vector<DiscountFactor> dfs = {
+        1.0,
+        0.9990151375768731,
+        0.99570502636871183,
+        0.99118260474528685,
+        0.98661167950906203,
+        0.9732592953359388,
+        0.94724424481038083,
+        0.89844996737120875,
+        0.85216647839921411,
+        0.80775477692556874,
+        0.76517289234200347,
+        0.72401019553182933,
+        0.68503909569219212,
+        0.64797499814013748,
+        0.61263171936255534,
+        0.5791942350748791,
+        0.43518868769953606
+    };
 
     const DayCounter& curveDayCounter=Actual360();
 
@@ -216,27 +220,29 @@ void CreditDefaultSwapTest::testCachedMarketValue() {
             new DiscountCurve(discountDates, dfs, curveDayCounter)));
 
     DayCounter dayCounter = Thirty360();
-    std::vector<Date> dates;
-    dates.push_back(evalDate);
-    dates.push_back(calendar.advance(evalDate, 6, Months, ModifiedFollowing));
-    dates.push_back(calendar.advance(evalDate, 1, Years, ModifiedFollowing));
-    dates.push_back(calendar.advance(evalDate, 2, Years, ModifiedFollowing));
-    dates.push_back(calendar.advance(evalDate, 3, Years, ModifiedFollowing));
-    dates.push_back(calendar.advance(evalDate, 4, Years, ModifiedFollowing));
-    dates.push_back(calendar.advance(evalDate, 5, Years, ModifiedFollowing));
-    dates.push_back(calendar.advance(evalDate, 7, Years, ModifiedFollowing));
-    dates.push_back(calendar.advance(evalDate,10, Years, ModifiedFollowing));
+    std::vector<Date> dates = {
+        evalDate,
+        calendar.advance(evalDate, 6, Months, ModifiedFollowing),
+        calendar.advance(evalDate, 1, Years, ModifiedFollowing),
+        calendar.advance(evalDate, 2, Years, ModifiedFollowing),
+        calendar.advance(evalDate, 3, Years, ModifiedFollowing),
+        calendar.advance(evalDate, 4, Years, ModifiedFollowing),
+        calendar.advance(evalDate, 5, Years, ModifiedFollowing),
+        calendar.advance(evalDate, 7, Years, ModifiedFollowing),
+        calendar.advance(evalDate,10, Years, ModifiedFollowing)
+    };
 
-    std::vector<Probability> defaultProbabilities;
-    defaultProbabilities.push_back(0.0000);
-    defaultProbabilities.push_back(0.0047);
-    defaultProbabilities.push_back(0.0093);
-    defaultProbabilities.push_back(0.0286);
-    defaultProbabilities.push_back(0.0619);
-    defaultProbabilities.push_back(0.0953);
-    defaultProbabilities.push_back(0.1508);
-    defaultProbabilities.push_back(0.2288);
-    defaultProbabilities.push_back(0.3666);
+    std::vector<Probability> defaultProbabilities = {
+        0.0000,
+        0.0047,
+        0.0093,
+        0.0286,
+        0.0619,
+        0.0953,
+        0.1508,
+        0.2288,
+        0.3666
+    };
 
     std::vector<Real> hazardRates;
     hazardRates.push_back(0.0);
@@ -466,7 +472,7 @@ void CreditDefaultSwapTest::testFairSpread() {
     fairCds.setPricingEngine(engine);
 
     Real fairNPV = fairCds.NPV();
-    Real tolerance = 1e-10;
+    Real tolerance = 1e-9;
 
     if (std::fabs(fairNPV) > tolerance)
         BOOST_ERROR(
@@ -534,7 +540,7 @@ void CreditDefaultSwapTest::testFairUpfront() {
     fairCds.setPricingEngine(engine);
 
     Real fairNPV = fairCds.NPV();
-    Real tolerance = 1e-10;
+    Real tolerance = 1e-9;
 
     if (std::fabs(fairNPV) > tolerance)
         BOOST_ERROR(
@@ -659,61 +665,88 @@ void CreditDefaultSwapTest::testIsdaEngine() {
                              795915.9787,
                              -4702034.688,
                              -4042340.999};
-    #ifndef QL_USE_INDEXED_COUPON
-    Real tolerance = 1.0e-6;
-    #else
-    /* The risk-free curve is a bit off. We might skip the tests
-       altogether and rely on running them with indexed coupons
-       disabled, but leaving them can be useful anyway. */
-    Real tolerance = 1.0e-3;
-    #endif
+    Real tolerance;
+    if (IborCoupon::usingAtParCoupons()) {
+        tolerance = 1.0e-6;
+    } else {
+        /* The risk-free curve is a bit off. We might skip the tests
+           altogether and rely on running them with indexed coupons
+           disabled, but leaving them can be useful anyway. */
+        tolerance = 1.0e-3;
+    }
 
     size_t l = 0;
 
-    for(size_t i = 0; i < sizeof(termDates) / sizeof(Date); i++) {
-        for(size_t j = 0; j < 2; j++) {
-            for(size_t k = 0; k < 2; k++) {
+    for (auto termDate : termDates) {
+        for (double spread : spreads) {
+            for (double& recoverie : recoveries) {
 
-            ext::shared_ptr<CreditDefaultSwap> quotedTrade =
-                MakeCreditDefaultSwap(termDates[i], spreads[j])
-                .withNominal(10000000.);
+                ext::shared_ptr<CreditDefaultSwap> quotedTrade =
+                    MakeCreditDefaultSwap(termDate, spread).withNominal(10000000.);
 
-            Rate h = quotedTrade->impliedHazardRate(0.,
-                                                    discountCurve,
-                                                    Actual365Fixed(),
-                                                    recoveries[k],
-                                                    1e-10,
-                                                    CreditDefaultSwap::ISDA);
+                Rate h = quotedTrade->impliedHazardRate(0., discountCurve, Actual365Fixed(),
+                                                        recoverie, 1e-10, CreditDefaultSwap::ISDA);
 
-            probabilityCurve.linkTo(
-                ext::make_shared<FlatHazardRate>(
-                    0, WeekendsOnly(), h, Actual365Fixed())
-                );
+                probabilityCurve.linkTo(
+                    ext::make_shared<FlatHazardRate>(0, WeekendsOnly(), h, Actual365Fixed()));
 
-            ext::shared_ptr<IsdaCdsEngine> engine = ext::make_shared<IsdaCdsEngine>(
-                probabilityCurve, recoveries[k], discountCurve,
-                boost::none, IsdaCdsEngine::Taylor, IsdaCdsEngine::HalfDayBias,
-                IsdaCdsEngine::Piecewise);
+                ext::shared_ptr<IsdaCdsEngine> engine = ext::make_shared<IsdaCdsEngine>(
+                    probabilityCurve, recoverie, discountCurve, boost::none, IsdaCdsEngine::Taylor,
+                    IsdaCdsEngine::HalfDayBias, IsdaCdsEngine::Piecewise);
 
-            ext::shared_ptr<CreditDefaultSwap> conventionalTrade =
-                MakeCreditDefaultSwap(termDates[i], 0.01)
-                .withNominal(10000000.)
-                .withPricingEngine(engine);
+                ext::shared_ptr<CreditDefaultSwap> conventionalTrade =
+                    MakeCreditDefaultSwap(termDate, 0.01)
+                        .withNominal(10000000.)
+                        .withPricingEngine(engine);
 
-            BOOST_CHECK_CLOSE(conventionalTrade->notional() * conventionalTrade->fairUpfront(),
-                              markitValues[l],
-                              tolerance);
-
-            l++;
+                BOOST_CHECK_CLOSE(conventionalTrade->notional() * conventionalTrade->fairUpfront(),
+                                  markitValues[l], tolerance);
 
+                l++;
             }
         }
     }
+}
 
+void CreditDefaultSwapTest::testAccrualRebateAmounts() {
+
+    BOOST_TEST_MESSAGE("Testing accrual rebate amounts on credit default swaps...");
+
+    SavedSettings backup;
+
+    // The accrual values are taken from various test results on the ISDA CDS model website
+    // https://www.cdsmodel.com/cdsmodel/documentation.html.
+
+    // Inputs
+    Real notional = 10000000;
+    Real spread = 0.0100;
+    Date maturity(20, Jun, 2014);
+
+    // key is trade date and value is expected accrual
+    typedef map<Date, Real> InputData;
+    InputData inputs = {
+        {Date(18, Mar, 2009), 24166.67},
+        {Date(19, Mar, 2009), 0.00},
+        {Date(20, Mar, 2009), 277.78},
+        {Date(23, Mar, 2009), 1111.11},
+        {Date(19, Jun, 2009), 25555.56},
+        {Date(20, Jun, 2009), 25833.33},
+        {Date(21, Jun, 2009), 0.00},
+        {Date(22, Jun, 2009), 277.78},
+        {Date(18, Jun, 2014), 25277.78},
+        {Date(19, Jun, 2014), 25555.56}
+    };
+
+    for (auto& input: inputs) {
+        Settings::instance().evaluationDate() = input.first;
+        CreditDefaultSwap cds = MakeCreditDefaultSwap(maturity, spread)
+            .withNominal(notional);
+        BOOST_CHECK_SMALL(input.second - cds.accrualRebate()->amount(), 0.01);
+    }
 }
 
 test_suite* CreditDefaultSwapTest::suite() {
-    test_suite* suite = BOOST_TEST_SUITE("Credit-default swap tests");
+    auto* suite = BOOST_TEST_SUITE("Credit-default swap tests");
     suite->add(QUANTLIB_TEST_CASE(&CreditDefaultSwapTest::testCachedValue));
     suite->add(QUANTLIB_TEST_CASE(
                               &CreditDefaultSwapTest::testCachedMarketValue));
@@ -722,5 +755,6 @@ test_suite* CreditDefaultSwapTest::suite() {
     suite->add(QUANTLIB_TEST_CASE(&CreditDefaultSwapTest::testFairSpread));
     suite->add(QUANTLIB_TEST_CASE(&CreditDefaultSwapTest::testFairUpfront));
     suite->add(QUANTLIB_TEST_CASE(&CreditDefaultSwapTest::testIsdaEngine));
+    suite->add(QUANTLIB_TEST_CASE(&CreditDefaultSwapTest::testAccrualRebateAmounts));
     return suite;
 }
