@@ -28,12 +28,17 @@
 class DayCounterTest {
    public:
     static void testActualActual();
+    static void testActualActualIsma();
     static void testActualActualWithSchedule();
+    static void testActualActualWithAnnualSchedule();
+    static void testActualActualWithSemiannualSchedule();
     static void testSimple();
     static void testOne();
     static void testBusiness252();
+    static void testThirty365();
     static void testThirty360_BondBasis();
     static void testThirty360_EurobondBasis();
+    static void testThirty360_German();
     static void testActual365_Canadian();
     static void testIntraday();
     static boost::unit_test_framework::test_suite* suite();
