@@ -208,18 +208,15 @@ namespace inflation_cpi_capfloor_test {
                 { Date( 2, June, 2070), 3.757542 },
                 { Date( 3, June, 2080), 3.651379 }
             };
-            const Size nominalDataLength = 33-1;
 
             std::vector<Date> nomD;
             std::vector<Rate> nomR;
-            for (Size i = 0; i < nominalDataLength; i++) {
-                nomD.push_back(nominalData[i].date);
-                nomR.push_back(nominalData[i].rate/100.0);
+            for (auto& i : nominalData) {
+                nomD.push_back(i.date);
+                nomR.push_back(i.rate / 100.0);
             }
-            ext::shared_ptr<YieldTermStructure>   nominalTS
-            =   ext::make_shared<InterpolatedZeroCurve<Linear>
-            >(nomD,nomR,dcNominal);
-
+            ext::shared_ptr<YieldTermStructure> nominalTS =
+                ext::make_shared<InterpolatedZeroCurve<Linear>>(nomD,nomR,dcNominal);
 
             nominalUK.linkTo(nominalTS);
 
@@ -269,7 +266,7 @@ namespace inflation_cpi_capfloor_test {
                                 new PiecewiseZeroInflationCurve<Linear>(
                                     evaluationDate, calendar, dcZCIIS, observationLag,
                                     ii->frequency(),ii->interpolated(), baseZeroRate,
-                                    Handle<YieldTermStructure>(nominalTS), helpers));
+                                    helpers));
             pCPIts->recalculate();
             cpiUK.linkTo(pCPIts);
             hii.linkTo(ii);
@@ -461,7 +458,7 @@ void InflationCPICapFloorTest::cpicapfloorpricer() {
 
 
 test_suite* InflationCPICapFloorTest::suite() {
-    test_suite* suite = BOOST_TEST_SUITE("CPIswaption tests");
+    auto* suite = BOOST_TEST_SUITE("CPIswaption tests");
 
     suite->add(QUANTLIB_TEST_CASE(&InflationCPICapFloorTest::cpicapfloorpricesurface));
     suite->add(QUANTLIB_TEST_CASE(&InflationCPICapFloorTest::cpicapfloorpricer));
