@@ -29,8 +29,6 @@
 #include <boost/test/unit_test.hpp>
 #endif
 
-#include <boost/timer/timer.hpp>
-
 /* Use BOOST_MSVC instead of _MSC_VER since some other vendors (Metrowerks,
    for example) also #define _MSC_VER
 */
@@ -41,24 +39,10 @@
 #  define BOOST_LIB_NAME boost_unit_test_framework
 #  include <boost/config/auto_link.hpp>
 #  undef BOOST_LIB_NAME
-#  define BOOST_LIB_NAME boost_timer
-#  include <boost/config/auto_link.hpp>
-#  undef BOOST_LIB_NAME
-#  define BOOST_LIB_NAME boost_chrono
-#  include <boost/config/auto_link.hpp>
-#  undef BOOST_LIB_NAME
-#  define BOOST_LIB_NAME boost_system
-#  include <boost/config/auto_link.hpp>
-#  undef BOOST_LIB_NAME
 #endif
 
-/* uncomment the following lines to unmask floating-point exceptions.
-   See http://www.wilmott.com/messageview.cfm?catid=10&threadid=9481
-*/
-//#  include <float.h>
-//   namespace { unsigned int u = _controlfp(_EM_INEXACT, _MCW_EM); }
-
 #endif
+
 #include "utilities.hpp"
 #include "speedlevel.hpp"
 
@@ -99,6 +83,7 @@
 #include "covariance.hpp"
 #include "creditdefaultswap.hpp"
 #include "creditriskplus.hpp"
+#include "crosscurrencyratehelpers.hpp"
 #include "curvestates.hpp"
 #include "dates.hpp"
 #include "daycounters.hpp"
@@ -189,6 +174,7 @@
 #include "rounding.hpp"
 #include "sampledcurve.hpp"
 #include "schedule.hpp"
+#include "settings.hpp"
 #include "shortratemodels.hpp"
 #include "sofrfutures.hpp"
 #include "solvers.hpp"
@@ -196,6 +182,7 @@
 #include "squarerootclvmodel.hpp"
 #include "swingoption.hpp"
 #include "stats.hpp"
+#include "subperiodcoupons.hpp"
 #include "swap.hpp"
 #include "swapforwardmappings.hpp"
 #include "swaption.hpp"
@@ -209,6 +196,7 @@
 #include "transformedgrid.hpp"
 #include "twoassetbarrieroption.hpp"
 #include "twoassetcorrelationoption.hpp"
+#include "ultimateforwardtermstructure.hpp"
 #include "variancegamma.hpp"
 #include "varianceoption.hpp"
 #include "varianceswaps.hpp"
@@ -218,22 +206,28 @@
 
 #include <iostream>
 #include <iomanip>
+#include <chrono>
 
 using namespace boost::unit_test_framework;
 
 namespace {
 
-    boost::timer::cpu_timer t;
+    decltype(std::chrono::steady_clock::now()) start;
+
+    void startTimer() {
+        start = std::chrono::steady_clock::now();
+    }
 
-    void startTimer() { t.start(); }
     void stopTimer() {
-        t.stop();
-        std::cout << "\nTests completed in ";
-        double seconds = t.elapsed().wall * 1e-9;
+        auto stop = std::chrono::steady_clock::now();
+
+        double seconds = std::chrono::duration_cast<std::chrono::milliseconds>(stop - start).count() * 1e-3;
         int hours = int(seconds/3600);
         seconds -= hours * 3600;
         int minutes = int(seconds/60);
         seconds -= minutes * 60;
+
+        std::cout << "\nTests completed in ";
         if (hours > 0)
             std::cout << hours << " h ";
         if (hours > 0 || minutes > 0)
@@ -261,7 +255,7 @@ namespace {
 #if defined(QL_ENABLE_SESSIONS)
 namespace QuantLib {
 
-    ThreadKey sessionId() { return 0; }
+    ThreadKey sessionId() { return {}; }
 
 }
 #endif
@@ -364,14 +358,14 @@ test_suite* init_unit_test_suite(int, char* []) {
     BOOST_TEST_MESSAGE(rule);
     BOOST_TEST_MESSAGE(header.str());
     BOOST_TEST_MESSAGE(rule);
-    test_suite* test = BOOST_TEST_SUITE("QuantLib test suite");
+    auto* test = BOOST_TEST_SUITE("QuantLib test suite");
 
     test->add(QUANTLIB_TEST_CASE(startTimer));
 
-    test->add(AmericanOptionTest::suite());
+    test->add(AmericanOptionTest::suite(speed));
     test->add(AndreasenHugeVolatilityInterplTest::suite(speed));
     test->add(ArrayTest::suite());
-    test->add(AsianOptionTest::suite());
+    test->add(AsianOptionTest::suite(speed));
     test->add(AssetSwapTest::suite()); // fails with QL_USE_INDEXED_COUPON
     test->add(AutocovariancesTest::suite());
     test->add(BarrierOptionTest::suite());
@@ -392,6 +386,7 @@ test_suite* init_unit_test_suite(int, char* []) {
     test->add(CovarianceTest::suite());
     test->add(CPISwapTest::suite());
     test->add(CreditDefaultSwapTest::suite());
+    test->add(CrossCurrencyRateHelpersTest::suite());
     test->add(CurveStatesTest::suite());
     test->add(DateTest::suite(speed));
     test->add(DayCounterTest::suite());
@@ -404,12 +399,12 @@ test_suite* init_unit_test_suite(int, char* []) {
     test->add(ExchangeRateTest::suite());
     test->add(FastFourierTransformTest::suite());
     test->add(FdHestonTest::suite(speed));
-    test->add(FdmLinearOpTest::suite());
+    test->add(FdmLinearOpTest::suite(speed));
     test->add(FdCevTest::suite(speed));
     test->add(FdCIRTest::suite(speed));
     test->add(FdSabrTest::suite(speed));
     test->add(FittedBondDiscountCurveTest::suite());
-    test->add(ForwardOptionTest::suite());
+    test->add(ForwardOptionTest::suite(speed));
     test->add(ForwardRateAgreementTest::suite());
     test->add(FunctionsTest::suite());
     test->add(GARCHTest::suite());
@@ -426,11 +421,11 @@ test_suite* init_unit_test_suite(int, char* []) {
     test->add(InstrumentTest::suite());
     test->add(IntegralTest::suite());
     test->add(InterestRateTest::suite());
-    test->add(InterpolationTest::suite());
+    test->add(InterpolationTest::suite(speed));
     test->add(JumpDiffusionTest::suite());
     test->add(LazyObjectTest::suite());
     test->add(LinearLeastSquaresRegressionTest::suite());
-    test->add(LookbackOptionTest::suite());
+    test->add(LookbackOptionTest::suite(speed));
     test->add(LowDiscrepancyTest::suite());
     test->add(MarketModelTest::suite(speed));
     test->add(MarketModelCmsTest::suite(speed));
@@ -440,7 +435,7 @@ test_suite* init_unit_test_suite(int, char* []) {
     test->add(MarketModelSmmCapletHomoCalibrationTest::suite());
     test->add(MarkovFunctionalTest::suite(speed));
     test->add(MatricesTest::suite());
-    test->add(MCLongstaffSchwartzEngineTest::suite());
+    test->add(MCLongstaffSchwartzEngineTest::suite(speed));
     test->add(MersenneTwisterTest::suite());
     test->add(MoneyTest::suite());
     test->add(NumericalDifferentiationTest::suite());
@@ -463,12 +458,15 @@ test_suite* init_unit_test_suite(int, char* []) {
     test->add(RoundingTest::suite());
     test->add(SampledCurveTest::suite());
     test->add(ScheduleTest::suite());
+    test->add(SettingsTest::suite());
     test->add(ShortRateModelTest::suite(speed)); // fails with QL_USE_INDEXED_COUPON
+    test->add(SofrFuturesTest::suite());
     test->add(Solver1DTest::suite());
     test->add(StatisticsTest::suite());
+    test->add(SubPeriodsCouponTest::suite());
     test->add(SwapTest::suite());
     test->add(SwapForwardMappingsTest::suite());
-    test->add(SwaptionTest::suite());
+    test->add(SwaptionTest::suite(speed));
     test->add(SwaptionVolatilityCubeTest::suite());
     test->add(SwaptionVolatilityMatrixTest::suite());
     test->add(TermStructureTest::suite());
@@ -477,15 +475,16 @@ test_suite* init_unit_test_suite(int, char* []) {
     test->add(TqrEigenDecompositionTest::suite());
     test->add(TracingTest::suite());
     test->add(TransformedGridTest::suite());
+    test->add(UltimateForwardTermStructureTest::suite());
     test->add(VarianceSwapTest::suite());
     test->add(VolatilityModelsTest::suite());
 
     // tests for experimental classes
     test->add(AmortizingBondTest::suite());
-    test->add(AsianOptionTest::experimental());
+    test->add(AsianOptionTest::experimental(speed));
     test->add(BasismodelsTest::suite());
     test->add(BarrierOptionTest::experimental());
-    test->add(DoubleBarrierOptionTest::experimental());
+    test->add(DoubleBarrierOptionTest::experimental(speed));
     test->add(BlackDeltaCalculatorTest::suite());
     test->add(CallableBondTest::suite());
     test->add(CatBondTest::suite());
@@ -518,7 +517,6 @@ test_suite* init_unit_test_suite(int, char* []) {
     test->add(PartialTimeBarrierOptionTest::suite());
     test->add(QuantoOptionTest::experimental());
     test->add(RiskNeutralDensityCalculatorTest::experimental(speed));
-    test->add(SofrFuturesTest::suite());
     test->add(SpreadOptionTest::suite());
     test->add(SquareRootCLVModelTest::experimental());
     test->add(SwingOptionTest::suite(speed));
