@@ -19,30 +19,30 @@
 
 #include "swingoption.hpp"
 #include "utilities.hpp"
-
-#include <ql/math/factorial.hpp>
-#include <ql/math/functional.hpp>
-#include <ql/math/richardsonextrapolation.hpp>
-#include <ql/math/distributions/normaldistribution.hpp>
-#include <ql/quotes/simplequote.hpp>
-#include <ql/time/daycounters/actualactual.hpp>
-#include <ql/instruments/vanillaoption.hpp>
-#include <ql/instruments/vanillaswingoption.hpp>
-#include <ql/math/randomnumbers/rngtraits.hpp>
-#include <ql/math/statistics/generalstatistics.hpp>
-#include <ql/termstructures/yield/zerocurve.hpp>
-#include <ql/processes/ornsteinuhlenbeckprocess.hpp>
-#include <ql/processes/blackscholesprocess.hpp>
-#include <ql/methods/montecarlo/multipathgenerator.hpp>
-#include <ql/pricingengines/vanilla/analyticeuropeanengine.hpp>
-#include <ql/experimental/processes/extouwithjumpsprocess.hpp>
-#include <ql/experimental/processes/extendedornsteinuhlenbeckprocess.hpp>
-#include <ql/pricingengines/blackformula.hpp>
-#include <ql/pricingengines/vanilla/fdsimplebsswingengine.hpp>
 #include <ql/experimental/finitedifferences/fdextoujumpvanillaengine.hpp>
 #include <ql/experimental/finitedifferences/fdsimpleextoujumpswingengine.hpp>
+#include <ql/experimental/processes/extendedornsteinuhlenbeckprocess.hpp>
+#include <ql/experimental/processes/extouwithjumpsprocess.hpp>
+#include <ql/instruments/vanillaoption.hpp>
+#include <ql/instruments/vanillaswingoption.hpp>
+#include <ql/math/distributions/normaldistribution.hpp>
+#include <ql/math/factorial.hpp>
+#include <ql/math/functional.hpp>
+#include <ql/math/randomnumbers/rngtraits.hpp>
+#include <ql/math/richardsonextrapolation.hpp>
+#include <ql/math/statistics/generalstatistics.hpp>
 #include <ql/methods/finitedifferences/meshers/exponentialjump1dmesher.hpp>
+#include <ql/methods/montecarlo/multipathgenerator.hpp>
+#include <ql/pricingengines/blackformula.hpp>
+#include <ql/pricingengines/vanilla/analyticeuropeanengine.hpp>
 #include <ql/pricingengines/vanilla/fdblackscholesvanillaengine.hpp>
+#include <ql/pricingengines/vanilla/fdsimplebsswingengine.hpp>
+#include <ql/processes/blackscholesprocess.hpp>
+#include <ql/processes/ornsteinuhlenbeckprocess.hpp>
+#include <ql/quotes/simplequote.hpp>
+#include <ql/termstructures/yield/zerocurve.hpp>
+#include <ql/time/daycounters/actualactual.hpp>
+#include <utility>
 
 
 using namespace QuantLib;
@@ -104,8 +104,8 @@ void SwingOptionTest::testExtendedOrnsteinUhlenbeckProcess() {
             Time t  = 0.0;
             Real q = 0.0;
             Real p = 0.0;
-            
-            PseudoRandom::rng_type rng(PseudoRandom::urng_type(1234u));
+
+            PseudoRandom::rng_type rng(PseudoRandom::urng_type(1234U));
 
             for (Size j=0; j < nTimeSteps; ++j) {
                 const Real dw = rng.next().value;
@@ -165,8 +165,7 @@ void SwingOptionTest::testFdmExponentialJump1dMesher() {
     for (Real x=1e-12; x < 1.0; x*=10) {
         const Real v = mesher.jumpSizeDistribution(x);
 
-        std::vector<Real>::iterator iter
-            = std::lower_bound(path.begin(), path.end(), x);
+        auto iter = std::lower_bound(path.begin(), path.end(), x);
         const Real q = std::distance(path.begin(), iter)/Real(n);
         QL_REQUIRE(std::fabs(q - v) < relTol1
                    || ((v < threshold) && std::fabs(q-v) < relTol2),
@@ -446,10 +445,10 @@ namespace swing_option_test {
       public:
         typedef FdSimpleExtOUJumpSwingEngine::Shape Shape;
 
-        SwingPdePricing(const ext::shared_ptr<ExtOUWithJumpsProcess>& process,
-                        const ext::shared_ptr<VanillaOption>& option,
-                        const ext::shared_ptr<Shape>& shape)
-        : process_(process), option_(option), shape_(shape) {}
+        SwingPdePricing(ext::shared_ptr<ExtOUWithJumpsProcess> process,
+                        ext::shared_ptr<VanillaOption> option,
+                        ext::shared_ptr<Shape> shape)
+        : process_(std::move(process)), option_(std::move(option)), shape_(std::move(shape)) {}
 
         Real operator()(Real x) const {
             const ext::shared_ptr<YieldTermStructure> rTS(
@@ -601,7 +600,7 @@ void SwingOptionTest::testKlugeChFVanillaPricing() {
 }
 
 test_suite* SwingOptionTest::suite(SpeedLevel speed) {
-    test_suite* suite = BOOST_TEST_SUITE("Swing-Option Test");
+    auto* suite = BOOST_TEST_SUITE("Swing-Option Test");
 
     suite->add(QUANTLIB_TEST_CASE(
         &SwingOptionTest::testExtendedOrnsteinUhlenbeckProcess));
